@@ -481,6 +481,19 @@ def generate_readme(checks):
         return True
     return False
 #-------------------------------------------------------------------------------
+def generate_ctest(checks):
+    # Generates the ClazyTests.cmake file
+    filename = clazy_source_path() + 'ClazyTests.cmake'
+
+    contents = "# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n\n"
+    for c in checks:
+        contents += 'add_test(NAME %s COMMAND python3 run_tests.py %s WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}/tests/)\n' % (c.name, c.name)
+
+    f = io.open(filename, 'w', newline='\n', encoding='utf8')
+    f.write(contents)
+    f.close()
+    return True
+#-------------------------------------------------------------------------------
 def generate_readmes_cmake_install(checks):
     old_contents = ""
     filename = clazy_source_path() + 'readmes.cmake'
@@ -534,6 +547,7 @@ if args.generate:
     generated = create_unittests(_checks) or generated
     generated = create_checks(_checks) or generated
     generated = generate_readmes_cmake_install(_checks) or generated
+    generated = generate_ctest(_checks) or generated
     if not generated:
         print("Nothing to do, everything is OK")
 else:
