@@ -51,7 +51,7 @@ class Stmt;
 }
 
 /**
- * This is the FrontendAction that is run with clazy is used as a plugin.
+ * This is the FrontendAction that is run when clazy is used as a clang plugin.
  */
 class ClazyASTAction
     : public clang::PluginASTAction
@@ -76,8 +76,7 @@ private:
 };
 
 /**
- * This is the FrontendAction that is run with clazy is used standalone instead of as a plugin.
- * i.e: when you run clazy-standalone, this is the invoked FrontendAction
+ * This is the FrontendAction that is run when clazy is invoked via clazy-standalone.
  */
 class ClazyStandaloneASTAction
     : public clang::ASTFrontendAction
@@ -86,6 +85,8 @@ public:
     explicit ClazyStandaloneASTAction(const std::string &checkList,
                                       const std::string &headerFilter,
                                       const std::string &ignoreDirs,
+                                      const std::string &exportFixesFilename,
+                                      const std::vector<std::string> &translationUnitPaths,
                                       ClazyContext::ClazyOptions = ClazyContext::ClazyOption_None);
 protected:
     std::unique_ptr<clang::ASTConsumer> CreateASTConsumer(clang::CompilerInstance &ci, llvm::StringRef) override;
@@ -93,6 +94,8 @@ private:
     const std::string m_checkList;
     const std::string m_headerFilter;
     const std::string m_ignoreDirs;
+    const std::string m_exportFixesFilename;
+    const std::vector<std::string> m_translationUnitPaths;
     const ClazyContext::ClazyOptions m_options;
 };
 
@@ -105,7 +108,7 @@ class ClazyASTConsumer
 {
 public:
     explicit ClazyASTConsumer(ClazyContext *context);
-    ~ClazyASTConsumer();
+    ~ClazyASTConsumer() override;
     bool shouldVisitImplicitCode() const { return m_context->isVisitImplicitCode(); }
 
     bool VisitDecl(clang::Decl *decl);
