@@ -47,7 +47,7 @@ class CXXBaseSpecifier;
 
 class ClazyContext;
 
-namespace TypeUtils
+namespace clazy
 {
 /**
  * Returns the sizeof(void*) for the platform we're compiling for, in bits.
@@ -78,10 +78,18 @@ struct QualTypeClassification {
  * The optional parameter body is in order to advise non-const-ref -> value, since the body
  * needs to be inspected to see if we that would compile.
  */
-bool classifyQualType(const ClazyContext *context, const clang::VarDecl *varDecl,
+bool classifyQualType(const ClazyContext *context, clang::QualType qualType, const clang::VarDecl *varDecl,
                       QualTypeClassification &classification,
                       clang::Stmt *body = nullptr);
 
+/**
+ * @brief Lighter version of classifyQualType in case you just want to know if it's small and trivially copyable&destructible
+ * @param context The clazy context
+ * @param qualType The QualType we're testing.
+ * @return true if the type specified by QualType (or its pointee) are small and trivially copyable/destructible.
+ */
+bool isSmallTrivial(const ClazyContext *context, clang::QualType qualType);
+
 /**
  * If qt is a reference, return it without a reference.
  * If qt is not a reference, return qt.
