@@ -122,8 +122,15 @@ bool containsNonConstMemberCall(clang::ParentMap *map, clang::Stmt *body, const
 
 // Returns true if there's an assignment to varDecl in body
 // Example: our_var = something_else
+bool isAssignedFrom(clang::Stmt *body, const clang::VarDecl *varDecl);
+
+// Returns true if varDecl is assigned to something
+// Example: something_else = our_var
 bool isAssignedTo(clang::Stmt *body, const clang::VarDecl *varDecl);
 
+// Returns whether the variable is returned in body
+bool isReturned(clang::Stmt *body, const clang::VarDecl *varDecl);
+
 // Returns true if a body of statements contains a function call that takes our variable (varDecl)
 // By ref or pointer
 bool isPassedToFunction(const StmtBodyRange &bodyRange, const clang::VarDecl *varDecl,
@@ -190,10 +197,10 @@ std::vector<clang::CallExpr *> callListForChain(clang::CallExpr *lastCallExpr);
 clang::CXXRecordDecl * rootBaseClass(clang::CXXRecordDecl *derived);
 
 // Returns the copy ctor for this class
-clang::CXXConstructorDecl *copyCtor(clang::CXXRecordDecl *);
+clang::CXXConstructorDecl *copyCtor(const clang::CXXRecordDecl *);
 
 // Returns the copy-assignment operator for this class
-clang::CXXMethodDecl *copyAssign(clang::CXXRecordDecl *);
+clang::CXXMethodDecl *copyAssign(const clang::CXXRecordDecl *);
 
 bool hasMember(clang::CXXRecordDecl *record, const std::string &memberTypeName);
 
