@@ -80,14 +80,14 @@ void FullyQualifiedMocTypes::VisitDecl(clang::Decl *decl)
     string qualifiedTypeName;
     string typeName;
     for (auto param : method->parameters()) {
-        QualType t = TypeUtils::pointeeQualType(param->getType());
+        QualType t = clazy::pointeeQualType(param->getType());
         if (!typeIsFullyQualified(t, /*by-ref*/ qualifiedTypeName, /*by-ref*/ typeName)) {
             emitWarning(method, string(accessSpecifierManager->qtAccessSpecifierTypeStr(qst)) + " arguments need to be fully-qualified (" + qualifiedTypeName + " instead of " + typeName + ")");
         }
     }
 
     if (qst == QtAccessSpecifier_Slot || qst == QtAccessSpecifier_Invokable) {
-        QualType returnT = TypeUtils::pointeeQualType(method->getReturnType());
+        QualType returnT = clazy::pointeeQualType(method->getReturnType());
         if (!typeIsFullyQualified(returnT, /*by-ref*/ qualifiedTypeName, /*by-ref*/ typeName)) {
             emitWarning(method, string(accessSpecifierManager->qtAccessSpecifierTypeStr(qst)) + " return types need to be fully-qualified (" + qualifiedTypeName + " instead of " + typeName + ")");
         }
@@ -106,6 +106,11 @@ bool FullyQualifiedMocTypes::typeIsFullyQualified(QualType t, string &qualifiedT
             return true;
 
         qualifiedTypeName = clazy::name(t, lo(), /*asWritten=*/ false);
+        if (qualifiedTypeName.empty() || qualifiedTypeName[0] == '(') {
+            // We don't care about (anonymous namespace)::
+            return true;
+        }
+
         return typeName == qualifiedTypeName;
     } else {
         return true;
@@ -149,19 +154,27 @@ bool FullyQualifiedMocTypes::handleQ_PROPERTY(CXXMethodDecl *method)
         if (enumRefs.size() == 1) {
             auto enumerator = dyn_cast<EnumConstantDecl>(enumRefs.at(0)->getDecl());
             if (enumerator && clazy::name(enumerator) == "ReadProperty") {
-                auto reinterprets = clazy::getStatements<CXXReinterpretCastExpr>(iff);
-                for (auto reinterpret : reinterprets) {
-                    QualType qt = TypeUtils::pointeeQualType(reinterpret->getTypeAsWritten());
-                    auto record = qt->getAsCXXRecordDecl();
-                    if (!record || !isGadget(record))
-                        continue;
+                auto switches = clazy::getStatements<SwitchStmt>(iff); // we only want the reinterpret_casts that are inside switches
+                for (auto s : switches) {
+                    auto reinterprets = clazy::getStatements<CXXReinterpretCastExpr>(s);
+                    for (auto reinterpret : reinterprets) {
+                        QualType qt = clazy::pointeeQualType(reinterpret->getTypeAsWritten());
+                        auto record = qt->getAsCXXRecordDecl();
+                        if (!record || !isGadget(record))
+                            continue;
 
-                    string nameAsWritten = clazy::name(qt, lo(), /*asWritten=*/ true);
-                    string fullyQualifiedName = clazy::name(qt, lo(), /*asWritten=*/ false);
-                    if (nameAsWritten != fullyQualifiedName) {
-                        // warn in the cxxrecorddecl, since we don't want to warn in the .moc files.
-                        // Ideally we would do some cross checking with the Q_PROPERTIES, but that's not in the AST
-                        emitWarning(clazy::getLocStart(method->getParent()), "Q_PROPERTY of type " + nameAsWritten + " should use full qualification (" + fullyQualifiedName + ")");
+                        string nameAsWritten = clazy::name(qt, lo(), /*asWritten=*/ true);
+                        string fullyQualifiedName = clazy::name(qt, lo(), /*asWritten=*/ false);
+                        if (fullyQualifiedName.empty() || fullyQualifiedName[0] == '(') {
+                            // We don't care about (anonymous namespace)::
+                            continue;
+                        }
+
+                        if (nameAsWritten != fullyQualifiedName) {
+                            // warn in the cxxrecorddecl, since we don't want to warn in the .moc files.
+                            // Ideally we would do some cross checking with the Q_PROPERTIES, but that's not in the AST
+                            emitWarning(clazy::getLocStart(method->getParent()), "Q_PROPERTY of type " + nameAsWritten + " should use full qualification (" + fullyQualifiedName + ")");
+                        }
                     }
                 }
                 return true;
