@@ -95,11 +95,9 @@ void QGetEnv::VisitStmt(clang::Stmt *stmt)
 
     if (!errorMsg.empty()) {
         std::vector<FixItHint> fixits;
-        if (fixitsEnabled()) {
-            const bool success = clazy::transformTwoCallsIntoOne(&m_astContext, qgetEnvCall, memberCall, replacement, fixits);
-            if (!success) {
-                queueManualFixitWarning(clazy::getLocStart(memberCall));
-            }
+        const bool success = clazy::transformTwoCallsIntoOne(&m_astContext, qgetEnvCall, memberCall, replacement, fixits);
+        if (!success) {
+            queueManualFixitWarning(clazy::getLocStart(memberCall));
         }
 
         errorMsg += " Use " + replacement + "() instead";
