@@ -1,22 +1,22 @@
 /*
   This file is part of the clazy static checker.
 
-  Copyright (C) 2016 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2016 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "incorrect-emit.h"
@@ -24,13 +24,24 @@
 #include "ClazyContext.h"
 #include "Utils.h"
 #include "HierarchyUtils.h"
-#include "QtUtils.h"
-#include "TypeUtils.h"
+#include "SourceCompatibilityHelpers.h"
 
-#include <clang/AST/AST.h>
 #include <clang/AST/DeclCXX.h>
 #include <clang/AST/ExprCXX.h>
-#include <clang/Lex/Lexer.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/IdentifierTable.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceManager.h>
+#include <clang/Lex/Token.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+
+#include <utility>
+
+namespace clang {
+class MacroInfo;
+}  // namespace clang
 
 using namespace clang;
 using namespace std;
@@ -62,7 +73,7 @@ void IncorrectEmit::VisitStmt(Stmt *stmt)
     if (!method || !accessSpecifierManager)
         return;
 
-    if (shouldIgnoreFile(getLocStart(stmt)))
+    if (shouldIgnoreFile(clazy::getLocStart(stmt)))
         return;
 
     if (Stmt *parent = clazy::parent(m_context->parentMap, methodCall)) {
@@ -105,12 +116,12 @@ void IncorrectEmit::checkCallSignalInsideCTOR(CXXMemberCallExpr *callExpr)
     if (clazy::getFirstParentOfType<LambdaExpr>(m_context->parentMap, callExpr) != nullptr)
         return; // Emit is inside a lambda, it's fine
 
-    emitWarning(getLocStart(callExpr), "Emitting inside constructor has no effect");
+    emitWarning(clazy::getLocStart(callExpr), "Emitting inside constructor probably has no effect");
 }
 
 bool IncorrectEmit::hasEmitKeyboard(CXXMemberCallExpr *call) const
 {
-    SourceLocation callLoc = getLocStart(call);
+    SourceLocation callLoc = clazy::getLocStart(call);
     if (callLoc.isMacroID())
         callLoc = sm().getFileLoc(callLoc);
 
