@@ -47,7 +47,7 @@
 using namespace clang;
 using namespace std;
 
-static bool shouldIgnoreClass(CXXRecordDecl *record)
+bool FunctionArgsByRef::shouldIgnoreClass(CXXRecordDecl *record)
 {
     if (!record)
         return false;
@@ -70,7 +70,7 @@ static bool shouldIgnoreClass(CXXRecordDecl *record)
     return clazy::contains(ignoreList, record->getQualifiedNameAsString());
 }
 
-static bool shouldIgnoreOperator(FunctionDecl *function)
+bool FunctionArgsByRef::shouldIgnoreOperator(FunctionDecl *function)
 {
     // Too many warnings in operator<<
     static const vector<StringRef> ignoreList = { "operator<<" };
@@ -78,7 +78,7 @@ static bool shouldIgnoreOperator(FunctionDecl *function)
     return clazy::contains(ignoreList, clazy::name(function));
 }
 
-static bool shouldIgnoreFunction(clang::FunctionDecl *function)
+bool FunctionArgsByRef::shouldIgnoreFunction(clang::FunctionDecl *function)
 {
     static const vector<string> qualifiedIgnoreList = {"QDBusMessage::createErrorReply", // Fixed in Qt6
                                                        "QMenu::exec", // Fixed in Qt6
@@ -114,12 +114,6 @@ void FunctionArgsByRef::processFunction(FunctionDecl *func)
     if (m_context->isQtDeveloper() && shouldIgnoreFunction(func))
         return;
 
-    const bool warnForOverriddenMethods = isOptionSet("warn-for-overridden-methods") || fixitsEnabled();
-    if (!warnForOverriddenMethods && Utils::methodOverrides(dyn_cast<CXXMethodDecl>(func))) {
-        // When overriding you can't change the signature. You should fix the base classes first
-        return;
-    }
-
     Stmt *body = func->getBody();
 
     auto funcParams = Utils::functionParameters(func);
@@ -159,26 +153,24 @@ void FunctionArgsByRef::processFunction(FunctionDecl *func)
 }
 
 void FunctionArgsByRef::addFixits(std::vector<FixItHint> &fixits, FunctionDecl *func, unsigned int parmIndex)
-{
-    if (fixitsEnabled()) {
-        for (auto funcRedecl : func->redecls()) {
-            auto funcParams = Utils::functionParameters(funcRedecl);
-            if (funcParams.size() <= parmIndex)
-                return;
+{    
+    for (auto funcRedecl : func->redecls()) {
+        auto funcParams = Utils::functionParameters(funcRedecl);
+        if (funcParams.size() <= parmIndex)
+            return;
 
-            ParmVarDecl *param = funcParams[parmIndex];
-            QualType paramQt = clazy::unrefQualType(param->getType());
+        ParmVarDecl *param = funcParams[parmIndex];
+        QualType paramQt = clazy::unrefQualType(param->getType());
 
-            const bool isConst = paramQt.isConstQualified();
+        const bool isConst = paramQt.isConstQualified();
 
-            if (!isConst) {
-                SourceLocation start = clazy::getLocStart(param);
-                fixits.push_back(clazy::createInsertion(start, "const "));
-            }
-
-            SourceLocation end = param->getLocation();
-            fixits.push_back(clazy::createInsertion(end, "&"));
+        if (!isConst) {
+            SourceLocation start = clazy::getLocStart(param);
+            fixits.push_back(clazy::createInsertion(start, "const "));
         }
+
+        SourceLocation end = param->getLocation();
+        fixits.push_back(clazy::createInsertion(end, "&"));
     }
 }
 
