@@ -30,7 +30,7 @@ struct MyRAII
 
 void testRAII()
 {
-    MyRAII m; // OK
+    MyRAII m; // OK, not whitelisted
 }
 
 void testFor()
@@ -53,3 +53,14 @@ void test4()
     FOO(QRect) r2; // OK
     r2.setX(0);
 }
+
+struct MyWhitelistedType
+{
+    MyWhitelistedType();
+    ~MyWhitelistedType();
+};
+
+void testUserWhitelist()
+{
+    MyWhitelistedType m; // OK, whitelisted
+}
